==> SingleR_1.0.0.tar.gz: SingleR/inst/doc/SingleR.R <==
## ---- echo=FALSE, results="hide", message=FALSE----------------------------
knitr::opts_chunk$set(error=FALSE, message=FALSE, warning=FALSE)
library(BiocStyle)

## --------------------------------------------------------------------------
library(SingleR)
hpca.se <- HumanPrimaryCellAtlasData()
hpca.se

## --------------------------------------------------------------------------
library(scRNAseq)
hESCs <- LaMannoBrainData('human-es')
hESCs <- hESCs[,1:100]

# Restrict to common genes between test and reference data:
library(scater)
common <- intersect(rownames(hESCs), rownames(hpca.se))
hpca.se <- hpca.se[common,]
hESCs <- hESCs[common,]
hESCs <- logNormCounts(hESCs)

pred.hpca <- SingleR(test = hESCs, ref = hpca.se, labels = hpca.se$label.main)
pred.hpca

## --------------------------------------------------------------------------
table(pred.hpca$labels)

## --------------------------------------------------------------------------
library(scRNAseq)
sceM <- MuraroPancreasData()

# One should normally do cell-based quality control at this point, but for
# brevity's sake, we will just remove the unlabelled libraries here.
sceM <- sceM[,!is.na(sceM$label)]
table(sceM$label)

sceM <- logNormCounts(sceM)

## --------------------------------------------------------------------------
sceG <- GrunPancreasData()
sceG <- sceG[,colSums(counts(sceG)) > 0]
sceG <- logNormCounts(sceG) 
sceG <- sceG[,1:100]

## --------------------------------------------------------------------------
common <- intersect(rownames(sceM), rownames(sceG))
sceM <- sceM[common,]
sceG <- sceG[common,]

## --------------------------------------------------------------------------
library(scran)
out <- pairwiseTTests(logcounts(sceM), sceM$label, direction="up")
markers <- getTopMarkers(out$statistics, out$pairs, n=10)

## --------------------------------------------------------------------------
pred <- SingleR(test=sceG, ref=sceM, labels=sceM$label, genes=markers)
table(pred$labels)

## --------------------------------------------------------------------------
label.markers <- lapply(markers, unlist, recursive=FALSE)
pred2 <- SingleR(test=sceG, ref=sceM, labels=sceM$label, genes=label.markers)
table(pred$labels, pred2$labels)

## --------------------------------------------------------------------------
plotScoreHeatmap(pred, show.labels = TRUE,
    annotation_col=data.frame(donor=sceG$donor,
        row.names=rownames(pred)))

## --------------------------------------------------------------------------
to.remove <- pruneScores(pred)
summary(to.remove)

## --------------------------------------------------------------------------
plotScoreDistribution(pred, show = "delta.med", ncol = 3, show.nmads = 3)

## --------------------------------------------------------------------------
new.pruned <- pred$labels
new.pruned[pruneScores(pred, nmads=5)] <- NA
table(new.pruned, useNA="always")

## --------------------------------------------------------------------------
# Beta cell-related markers
plotHeatmap(sceG, order_columns_by=list(I(pred$labels)),
    features=unique(unlist(metadata(pred)$de.genes$beta))) 

## ---- fig.show="hide"------------------------------------------------------
for (lab in names(metadata(pred)$de.genes)) {
    plotHeatmap(sceG, order_columns_by=list(I(pred$labels)), 
        features=unique(unlist(metadata(pred)$de.genes[[lab]]))) 
}

## ---- echo=FALSE, message=FALSE--------------------------------------------
library(knitr)
library(SingleR)
ref <- BlueprintEncodeData()
samples <- cbind(ref$label.main, ref$label.fine)
colnames(samples) <- c("label.main", "label.fine")

kable(unique(samples), format = "markdown")

## ---- echo=FALSE, message=FALSE--------------------------------------------
library(knitr)
library(SingleR)
ref <- HumanPrimaryCellAtlasData()
samples <- cbind(ref$label.main, ref$label.fine)
colnames(samples) <- c("label.main", "label.fine")

kable(unique(samples), format = "markdown")

## ---- echo=FALSE, message=FALSE--------------------------------------------
library(knitr)
library(SingleR)
ref <- DatabaseImmuneCellExpressionData()
samples <- cbind(ref$label.main, ref$label.fine)
colnames(samples) <- c("label.main", "label.fine")

kable(unique(samples), format = "markdown")

## ---- echo=FALSE, message=FALSE--------------------------------------------
library(knitr)
library(SingleR)
ref <- NovershternHematopoieticData()
samples <- cbind(ref$label.main, ref$label.fine)
colnames(samples) <- c("label.main", "label.fine")

kable(unique(samples), format = "markdown")

## ---- echo=FALSE, message=FALSE--------------------------------------------
library(knitr)
library(SingleR)
ref <- MonacoImmuneData()
samples <- cbind(ref$label.main, ref$label.fine)
colnames(samples) <- c("label.main", "label.fine")

kable(unique(samples), format = "markdown")

## ---- echo=FALSE, message=FALSE--------------------------------------------
library(knitr)
library(SingleR)
ref <- ImmGenData()
samples <- cbind(ref$label.main, ref$label.fine)
colnames(samples) <- c("label.main", "label.fine")

kable(unique(samples), format = "markdown")

## ---- echo=FALSE, message=FALSE--------------------------------------------
library(knitr)
library(SingleR)
ref <- MouseRNAseqData()
samples <- cbind(ref$label.main, ref$label.fine)
colnames(samples) <- c("label.main", "label.fine")

kable(unique(samples), format = "markdown")

## --------------------------------------------------------------------------
trained <- trainSingleR(sceM, labels=sceM$label, genes=markers)
pred2b <- classifySingleR(sceG, trained)
table(pred$labels, pred2b$labels)

## --------------------------------------------------------------------------
sessionInfo()

==> SingleR_1.0.1.tar.gz: SingleR/inst/doc/SingleR.R <==
## ---- echo=FALSE, results="hide", message=FALSE-------------------------------
knitr::opts_chunk$set(error=FALSE, message=FALSE, warning=FALSE)
library(BiocStyle)

## -----------------------------------------------------------------------------
library(SingleR)
hpca.se <- HumanPrimaryCellAtlasData()
hpca.se

## -----------------------------------------------------------------------------
library(scRNAseq)
hESCs <- LaMannoBrainData('human-es')
hESCs <- hESCs[,1:100]

# Restrict to common genes between test and reference data:
library(scater)
common <- intersect(rownames(hESCs), rownames(hpca.se))
hpca.se <- hpca.se[common,]
hESCs <- hESCs[common,]
hESCs <- logNormCounts(hESCs)

pred.hpca <- SingleR(test = hESCs, ref = hpca.se, labels = hpca.se$label.main)
pred.hpca

## -----------------------------------------------------------------------------
table(pred.hpca$labels)

## -----------------------------------------------------------------------------
library(scRNAseq)
sceM <- MuraroPancreasData()

# One should normally do cell-based quality control at this point, but for
# brevity's sake, we will just remove the unlabelled libraries here.
sceM <- sceM[,!is.na(sceM$label)]
table(sceM$label)

sceM <- logNormCounts(sceM)

## -----------------------------------------------------------------------------
sceG <- GrunPancreasData()
sceG <- sceG[,colSums(counts(sceG)) > 0]
sceG <- logNormCounts(sceG) 
sceG <- sceG[,1:100]

## -----------------------------------------------------------------------------
common <- intersect(rownames(sceM), rownames(sceG))
sceM <- sceM[common,]
sceG <- sceG[common,]

## -----------------------------------------------------------------------------
library(scran)
out <- pairwiseTTests(logcounts(sceM), sceM$label, direction="up")
markers <- getTopMarkers(out$statistics, out$pairs, n=10)

## -----------------------------------------------------------------------------
pred <- SingleR(test=sceG, ref=sceM, labels=sceM$label, genes=markers)
table(pred$labels)

## -----------------------------------------------------------------------------
label.markers <- lapply(markers, unlist, recursive=FALSE)
pred2 <- SingleR(test=sceG, ref=sceM, labels=sceM$label, genes=label.markers)
table(pred$labels, pred2$labels)

## -----------------------------------------------------------------------------
plotScoreHeatmap(pred, show.labels = TRUE,
    annotation_col=data.frame(donor=sceG$donor,
        row.names=rownames(pred)))

## -----------------------------------------------------------------------------
to.remove <- pruneScores(pred)
summary(to.remove)

## -----------------------------------------------------------------------------
plotScoreDistribution(pred, show = "delta.med", ncol = 3, show.nmads = 3)

## -----------------------------------------------------------------------------
new.pruned <- pred$labels
new.pruned[pruneScores(pred, nmads=5)] <- NA
table(new.pruned, useNA="always")

## -----------------------------------------------------------------------------
# Beta cell-related markers
plotHeatmap(sceG, order_columns_by=list(I(pred$labels)),
    features=unique(unlist(metadata(pred)$de.genes$beta))) 

## ---- fig.show="hide"---------------------------------------------------------
for (lab in names(metadata(pred)$de.genes)) {
    plotHeatmap(sceG, order_columns_by=list(I(pred$labels)), 
        features=unique(unlist(metadata(pred)$de.genes[[lab]]))) 
}

## ---- echo=FALSE, message=FALSE-----------------------------------------------
library(knitr)
library(SingleR)
ref <- BlueprintEncodeData()
samples <- cbind(ref$label.main, ref$label.fine)
colnames(samples) <- c("label.main", "label.fine")

kable(unique(samples), format = "markdown")

## ---- echo=FALSE, message=FALSE-----------------------------------------------
library(knitr)
library(SingleR)
ref <- HumanPrimaryCellAtlasData()
samples <- cbind(ref$label.main, ref$label.fine)
colnames(samples) <- c("label.main", "label.fine")

kable(unique(samples), format = "markdown")

## ---- echo=FALSE, message=FALSE-----------------------------------------------
library(knitr)
library(SingleR)
ref <- DatabaseImmuneCellExpressionData()
samples <- cbind(ref$label.main, ref$label.fine)
colnames(samples) <- c("label.main", "label.fine")

kable(unique(samples), format = "markdown")

## ---- echo=FALSE, message=FALSE-----------------------------------------------
library(knitr)
library(SingleR)
ref <- NovershternHematopoieticData()
samples <- cbind(ref$label.main, ref$label.fine)
colnames(samples) <- c("label.main", "label.fine")

kable(unique(samples), format = "markdown")

## ---- echo=FALSE, message=FALSE-----------------------------------------------
library(knitr)
library(SingleR)
ref <- MonacoImmuneData()
samples <- cbind(ref$label.main, ref$label.fine)
colnames(samples) <- c("label.main", "label.fine")

kable(unique(samples), format = "markdown")

## ---- echo=FALSE, message=FALSE-----------------------------------------------
library(knitr)
library(SingleR)
ref <- ImmGenData()
samples <- cbind(ref$label.main, ref$label.fine)
colnames(samples) <- c("label.main", "label.fine")

kable(unique(samples), format = "markdown")

## ---- echo=FALSE, message=FALSE-----------------------------------------------
library(knitr)
library(SingleR)
ref <- MouseRNAseqData()
samples <- cbind(ref$label.main, ref$label.fine)
colnames(samples) <- c("label.main", "label.fine")

kable(unique(samples), format = "markdown")

## -----------------------------------------------------------------------------
hpca.se <- HumanPrimaryCellAtlasData()
bp.se <- BlueprintEncodeData()

hESCs <- LaMannoBrainData('human-es')
hESCs <- hESCs[,1:100]

# Restrict to common genes between reference datasets:
common.refs <- intersect(rownames(bp.se), rownames(hpca.se))
hpca.se <- hpca.se[common.refs,]
bp.se <- bp.se[common.refs,]

# Restrict to common genes between test and reference data:
common <- intersect(rownames(hESCs), rownames(hpca.se))
hpca.se <- hpca.se[common,]
bp.se <- bp.se[common,]
hESCs <- hESCs[common,]
hESCs <- logNormCounts(hESCs)

pred.hpca <- SingleR(test = hESCs, ref = hpca.se, labels = hpca.se$label.main)
table(pred.hpca$labels)
pred.bp <- SingleR(test = hESCs, ref = bp.se, labels = bp.se$label.main)
table(pred.bp$labels)

combined.preds <- combineResults(list(hpca = pred.hpca, bp = pred.bp))
table(combined.preds$labels)

## -----------------------------------------------------------------------------
trained <- trainSingleR(sceM, labels=sceM$label, genes=markers)
pred2b <- classifySingleR(sceG, trained)
table(pred$labels, pred2b$labels)

## -----------------------------------------------------------------------------
sessionInfo()
